<?php

/**
 * 2007-2020 PrestaShop
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 * @author    PrestaShop SA <contact@prestashop.com>
 * @copyright 2007-2020 PrestaShop SA
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 *  International Registered Trademark & Property of PrestaShop SA
 */

if (!defined('_PS_VERSION_')) {
    exit;
}

/**
 *
 */
class CancelAplazoController extends ModuleAdminController
{
    /**
     *
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     *
     */
    public function initContent()
    {
        parent::initContent();

        $order_id = Tools::getValue('id_order');
        $reason = Tools::getValue('reason');
        $order = new Order($order_id);
        $total = (float) $order->total_paid;
        $date = date('c');
        $cancel = null;
        $error = null;
        if (ApalzoCancelPaymentModel::isValid($order_id)) {
            return '';
        }
        try {

            /**
             * 
             */
            $service = new AplazoService(true);
            $body = $service->refund($order->id_cart, $reason, $total);
            $cancel = ApalzoCancelPaymentModel::create(compact('order_id', 'reason', 'date'));
            $order->setCurrentState((int) Configuration::get('PS_OS_REFUND'));
        } catch (Exception $e) {
            $error = 'An error occurred while trying to cancel the payment ' . $e->getMessage();
        }

        $url = $this->context->link->getAdminLink('CancelAplazo', true, null, array('vieworder' => 'cancel', 'id_order' => $order->id, 'action' => 'actionCancelOrder'));
        $params = compact('order', 'cancel', 'url',  'error');
        $output = $this->context->smarty->fetch(
            version_compare(_PS_VERSION_, '1.7', '<') ? 'display_admin_order.tpl' : 'module:aplazo/views/templates/hook/display_admin_order.tpl',
            $params
        );

        die(json_encode(['cancel' => $cancel,  'html' => $output]));
    }

    /**
     *
     */
    public function viewAccess($disable = false)
    {
        return true;
    }
}
