<?php

/**
 * 2007-2022 PrestaShop
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 *  @author PrestaShop SA <contact@prestashop.com>
 *  @copyright  2007-2022 PrestaShop SA
 *  @license    http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 *  International Registered Trademark & Property of PrestaShop SA
 */

if (!defined('_PS_VERSION_')) {
    exit;
}

/**
 *
 */
class AplazoPaymentModuleFrontController extends ModuleFrontController
{
    public $ssl = true;
    public $display_column_left = false;

    /**
     * @see FrontController::initContent()
     */
    public function initContent()
    {
        parent::initContent();
        $cart = $this->context->cart;
        if (!$this->module->checkCurrency($cart)) {
            Tools::redirect('index.php?controller=order');
        }

        $total = (float) $cart->getOrderTotal(true, Cart::BOTH);
        $amount = $total / 5;
        $logo = _PS_BASE_URL_ . __PS_BASE_URI__ . "modules/aplazo/views/img/aplazo-logo.png";

        $titles = [];
        for ($i = 1; $i <= 4; $i++) {
            $_t =  strtotime("+" . ($i * 15) . " day");
            array_push($titles, date('d', $_t) . ' ' . $this->getMonths()[date('m', $_t) - 1]);
        }

        $this->context->smarty->assign(
            [
                'total' => $total,
                'logo' => $logo,
                'amount' => $amount,
                'titles' => $titles,
                'nbProducts' => $cart->nbProducts(),
                'cust_currency' => $cart->id_currency,
                'currencies' => $this->module->getCurrency((int)$cart->id_currency),
                'total' => $cart->getOrderTotal(true, Cart::BOTH),
                'this_path' => $this->module->getPathUri(),
                'this_path_bw' => $this->module->getPathUri(),
                'this_path_ssl' => Tools::getShopDomainSsl(true, true) . __PS_BASE_URI__ .
                    'modules/' . $this->module->name . '/'
            ]
        );

        $this->setTemplate('payment_execution.tpl');
    }

    /**
     *
     */
    public function getMonths()
    {
        $months = [
            $this->module->l('of January'),
            $this->module->l('of February'),
            $this->module->l('of March'),
            $this->module->l('of April'),
            $this->module->l('of May'),
            $this->module->l('of June'),
            $this->module->l('of July'),
            $this->module->l('of August'),
            $this->module->l('of September'),
            $this->module->l('of October'),
            $this->module->l('of November'),
            $this->module->l('of December'),
        ];

        return $months;
    }
}
