<?php

/**
 * 2007-2022 PrestaShop
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 *  @author    PrestaShop SA <contact@prestashop.com>
 *  @copyright 2007-2022 PrestaShop SA
 *  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 *  International Registered Trademark & Property of PrestaShop SA
 */

if (!defined('_PS_VERSION_')) {
    exit;
}

class AplazoProcessModuleFrontController extends ModuleFrontController
{

    /**
     * @var Customer
     */
    protected $customer;

    /**
     * @var Country
     */
    protected $country;

    /**
     * @var AplazoService
     */
    protected $service;


    public function postProcess()
    {
        $this->body = json_decode(Tools::file_get_contents('php://input'), true);
        $token =  Tools::getValue('aplazo_token');

        $loanId = $this->body['loanId'];
        $cartId = $this->body['cartId'];
        $status = $this->body['status'];
        $totalAmount = $this->body['totalAmount'];

        // LogAp::info('APLAZO CALL :' . json_encode([$loanId,  $cartId, $status, $totalAmount]));

        if (!ApalzoTokenCartModel::isValid($token, $cartId, $loanId)) {
            die(json_encode(['Ok' => false, 'message' => 'invalid token ']));
        }

        if ($status == "Activo") {
            $cart = new Cart($cartId);
            $customer = new Customer($cart->id_customer);

            /**
             * Validations
             */
            $this->module->validateOrder(
                (int) $cart->id,
                Configuration::get('PS_OS_PAYMENT'),
                (float) $totalAmount,
                $this->module->displayName,
                '',
                array(),
                (int) $cart->id_currency,
                false,
                $customer->secure_key
            );

            $id_order = HelperAp::getOrderByCartId((int) $cart->id);
            $order = new Order($id_order);
            $payments = $order->getOrderPayments();
            foreach ($payments as $item) {
                if ($item->payment_method == $this->module->displayName) {
                    $item->transaction_id = $loanId;
                    $item->save();
                }
            }
        }
        die(json_encode(['Ok' => true]));
    }
}
