<?php
/**
 * 2007-2022 PrestaShop
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 *  @author    PrestaShop SA <contact@prestashop.com>
 *  @copyright 2007-2022 PrestaShop SA
 *  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 *  International Registered Trademark & Property of PrestaShop SA
 */

if (!defined('_PS_VERSION_')) {
    exit;
}

class AplazoRedirectModuleFrontController extends ModuleFrontController
{
    /**
     * @var Customer
     */
    protected $customer;

    /**
     * @var float
     */
    protected $total;

    /**
     * @var Currency
     */
    protected $currency;

    /**
     * @var Country
     */
    protected $country;

    /**
     * @var Order
     */
    protected $order;

    /**
     * @var AplazoService
     */
    protected $service;

    /**
     *
     */
    public function __construct()
    {
        parent::__construct();

        /**
         * register JS for each version
         */
        if (version_compare(_PS_VERSION_, '1.7', '<')) {
            $this->addJquery();
            $this->addJS('modules/aplazo/views/js/front.js');
            $this->addCss('modules/aplazo/views/css/front.css');
        } else {
            $this->registerJavascript('aplazo', 'modules/aplazo/views/js/front.js', null, ['priority' => 0]);
            $this->registerStylesheet('aplazo', 'modules/aplazo/views/css/front.css', null, ['priority' => 0]);
        }
    }

    public function postProcess()
    {
        try {
            $this->service = new AplazoService(true);
            $this->_cart = $this->context->cart;
            $this->customer = new Customer($this->_cart->id_customer);
            $loan =  $this->service->createLoan($this->_cart);
            Tools::redirect($loan);
        } catch (Exception $error) {
            /**
             * Oops, an error occured.
             */
            LogAp::error($error);
            return $this->displayError('An error occurred while trying to redirect the customer');
        }

        /**
         * Oops, an error occured.
         */
        return $this->displayError('An error occurred while trying to redirect the customer');
    }

    protected function displayError($message)
    {
        array_push($this->errors, $this->module->l($message));
        $this->context->smarty->assign([
            'errors' => $this->errors,
            'path' => $this->context->link->getPageLink('order', null, null, 'step=3')
        ]);
        $this->setTemplate(
            version_compare(_PS_VERSION_, '1.7', '<') ? 'error.tpl' :  'module:aplazo/views/templates/front/error.tpl'
        );
    }
}
