<?php
/**
 * 2007-2022 PrestaShop
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 *  @author    PrestaShop SA <contact@prestashop.com>
 *  @copyright 2007-2022 PrestaShop SA
 *  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 *  International Registered Trademark & Property of PrestaShop SA
 */

if (!defined('_PS_VERSION_')) {
    exit;
}

class AplazoSuccessModuleFrontController extends ModuleFrontController
{
    /**
     * @var string
     */
    protected $cart_id;

    /**
     * @var AplazoService
     */
    protected $service;

    /**
     *
     */
    public function __construct()
    {
        parent::__construct();

        /**
         * register JS for each version
         */
        if (version_compare(_PS_VERSION_, '1.7', '<')) {
            $this->addJquery();
            $this->addJS('modules/aplazo/views/js/front.js');
            $this->addCss('modules/aplazo/views/css/front.css');
        } else {
            $this->registerJavascript('aplazo', 'modules/aplazo/views/js/front.js', null, ['priority' => 0]);
            $this->registerStylesheet('aplazo', 'modules/aplazo/views/css/front.css', null, ['priority' => 0]);
        }
    }

    /**
     *
     */
    public function initContent()
    {
        parent::initContent();
        if (!$this->module->active) {
            die;
        }

        $this->_cart_id = Tools::getValue('cart_id');
        $this->_cart = new Cart($this->_cart_id);
        $this->service = new AplazoService();
        $this->order = new Order(HelperAp::getOrderByCartId((int) $this->_cart_id));
        $this->customer = new Customer($this->_cart->id_customer);
        if ($this->order->id != 0) {
            $url = 'index.php?controller=order-confirmation&id_cart=' .
                (int) $this->_cart->id . '&id_module=' .
                (int) $this->module->id . '&id_order=' .
                $this->order->id . '&key=' . $this->customer->secure_key;
            Tools::redirect($url); 
            return;
        } else {

            /**
             * set url
             */
            $paymentHasFinished = $this->paymentHasFinished($this->_cart);

            /**
             * context
             */

            $this->context->smarty->assign(compact('paymentHasFinished'));


            $this->setTemplate(
                version_compare(_PS_VERSION_, '1.7', '<') ?
                    'success_16.tpl' : 'module:aplazo/views/templates/front/success.tpl'
            );
        }
    }

    /**
     * Payment Link
     *
     * $cart Cart
     *
     * @return string
     */
    public function paymentHasFinished($cart)
    {
        return Context::getContext()->link->getModuleLink("aplazo", "finished", ['cart_id' => $cart->id]);
    }
}
