<?php
/**
 * 2007-2022 PrestaShop
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 *  @author    PrestaShop SA <contact@prestashop.com>
 *  @copyright 2007-2022 PrestaShop SA
 *  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 *  International Registered Trademark & Property of PrestaShop SA
 */

if (!defined('_PS_VERSION_')) {
    exit;
}

class ArrAp
{

    /**
     * Determine whether the given value is array accessible
     *
     * @param  mixed  $value
     *
     * @return bool
     */
    public static function accessible($value)
    {
        return is_array($value);
    }

    /**
     *
     * @param array $arr
     * @param string $key
     * @param mixed $default
     *
     * @return mixed
     */
    public static function get($arr, $key, $default = null)
    {
        if (!static::accessible($arr) || is_null($key)) {
            return $default;
        }

        if (static::exists($arr, $key)) {
            return $arr[$key];
        }

        if (strpos($key, '.') === false) {
            return $arr[$key] ?? $default;
        }

        foreach (explode('.', $key) as $segment) {
            if (static::accessible($arr) && static::exists($arr, $segment)) {
                $arr = $arr[$segment];
            } else {
                return $default;
            }
        }
        return $arr;
    }


    /**
     * Determine if the given key exists in the provided array
     *
     * @param  \ArrayAccess|array  $array
     * @param  string|int  $key
     * @return bool
     */
    public static function exists($array, $key)
    {
        return array_key_exists($key, $array);
    }
}
