<?php
/**
 * 2007-2022 PrestaShop
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 *  @author    PrestaShop SA <contact@prestashop.com>
 *  @copyright 2007-2022 PrestaShop SA
 *  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 *  International Registered Trademark & Property of PrestaShop SA
 */

if (!defined('_PS_VERSION_')) {
    exit;
}

class HttpAp
{
    /**
     * @var string
     */
    public $urlBase;

    /**
     * @var mixed
     */
    public $body;

    /**
     * @var int
     */
    public $httpCode;

    /**
     * @var array
     */
    public $headers;

    /**
     * @var array
     */
    public $requestHeaders;

    /**
     * @param string $urlBase
     */
    public function __construct($urlBase)
    {
        $this->urlBase = $urlBase;
        $this->requestHeaders = [];
    }

    /**
     *
     */
    public function put($url, $values, $options = [])
    {
        $operation = curl_init();
        $headers = array_merge($this->requestHeaders, ArrAp::get($options, 'headers', []));
        curl_setopt($operation, CURLOPT_URL, $this->urlBase . '/' . $url);
        curl_setopt($operation, CURLOPT_POST, true);
        curl_setopt($operation, CURLOPT_POSTFIELDS, $values);
        curl_setopt($operation, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($operation, CURLOPT_CONNECTTIMEOUT, 25);
        curl_setopt($operation, CURLOPT_SSL_VERIFYPEER, true);
        curl_setopt($operation, CURLOPT_TIMEOUT, 60);
        curl_setopt($operation, CURLOPT_HTTPHEADER, $headers);
        curl_setopt($operation, CURLOPT_HEADER, true);
        curl_setopt($operation, CURLOPT_CUSTOMREQUEST, 'PUT');
        $this->response = curl_exec($operation);
        $this->httpCode = curl_getinfo($operation, CURLINFO_HTTP_CODE);
        $this->header_size = curl_getinfo($operation, CURLINFO_HEADER_SIZE);
        $this->processHeaders();
        $this->processBody();
        curl_close($operation);
        if ($this->httpCode >= 400 && $this->httpCode <= 500) {
            throw new HttpApClientError($this);
        }
        return $this;
    }

    /**
     *
     */
    public function post($url, $values, $options = [])
    {
        $operation = curl_init();
        $headers = array_merge($this->requestHeaders, ArrAp::get($options, 'headers', []));

        curl_setopt($operation, CURLOPT_URL, $this->urlBase . '/' . $url);
        curl_setopt($operation, CURLOPT_POST, true);
        curl_setopt($operation, CURLOPT_POSTFIELDS, $values);
        curl_setopt($operation, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($operation, CURLOPT_CONNECTTIMEOUT, 25);
        curl_setopt($operation, CURLOPT_SSL_VERIFYPEER, true);
        curl_setopt($operation, CURLOPT_TIMEOUT, 60);
        curl_setopt($operation, CURLOPT_HTTPHEADER, $headers);
        curl_setopt($operation, CURLOPT_HEADER, true);
        curl_setopt($operation, CURLOPT_CUSTOMREQUEST, 'POST');
        $this->response = curl_exec($operation);
        $this->httpCode = curl_getinfo($operation, CURLINFO_HTTP_CODE);
        $this->header_size = curl_getinfo($operation, CURLINFO_HEADER_SIZE);
        $this->processHeaders();
        $this->processBody();
        curl_close($operation);
        if ($this->httpCode >= 400 && $this->httpCode <= 500) {
            throw new HttpApClientError($this);
        }
        return $this;
    }

    /**
     *
     */
    public function get($url, $options = [])
    {
        $operation = curl_init();
        $headers = array_merge($this->requestHeaders, ArrAp::get($options, 'headers', []));
        $params = ArrAp::get($options, 'params', []);
        $url = empty($params) ? $url : "{$url}?" . http_build_query($params);
        curl_setopt($operation, CURLOPT_URL, $this->urlBase . '/' . $url);
        curl_setopt($operation, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($operation, CURLOPT_CONNECTTIMEOUT, 25);
        curl_setopt($operation, CURLOPT_SSL_VERIFYPEER, true);
        curl_setopt($operation, CURLOPT_TIMEOUT, 60);
        curl_setopt($operation, CURLOPT_HTTPHEADER, $headers);
        curl_setopt($operation, CURLOPT_HEADER, true);
        $this->response = curl_exec($operation);
        $this->httpCode = curl_getinfo($operation, CURLINFO_HTTP_CODE);
        $this->header_size = curl_getinfo($operation, CURLINFO_HEADER_SIZE);
        $this->processHeaders();
        $this->processBody();
        curl_close($operation);
        if ($this->httpCode >= 400 && $this->httpCode <= 500) {
            throw new HttpApClientError($this);
        }
        return $this;
    }

    /**
     *
     */
    public function delete($url, $options = [])
    {
        $operation = curl_init();
        $headers = array_merge($this->requestHeaders, ArrAp::get($options, 'headers', []));
        curl_setopt($operation, CURLOPT_URL, $this->urlBase . '/' . $url);
        curl_setopt($operation, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($operation, CURLOPT_CONNECTTIMEOUT, 25);
        curl_setopt($operation, CURLOPT_SSL_VERIFYPEER, true);
        curl_setopt($operation, CURLOPT_TIMEOUT, 60);
        curl_setopt($operation, CURLOPT_HTTPHEADER, $headers);
        curl_setopt($operation, CURLOPT_HEADER, true);
        curl_setopt($operation, CURLOPT_CUSTOMREQUEST, 'DELETE');
        $this->response = curl_exec($operation);
        $this->httpCode = curl_getinfo($operation, CURLINFO_HTTP_CODE);
        $this->header_size = curl_getinfo($operation, CURLINFO_HEADER_SIZE);
        $this->processHeaders();
        $this->processBody();
        curl_close($operation);
        if ($this->httpCode >= 400 && $this->httpCode <= 500) {
            throw new HttpApClientError($this);
        }
        return $this;
    }

    /**
     *
     */
    private function processHeaders()
    {
        $headers = explode("\r\n", Tools::substr($this->response, 0, $this->header_size));
        $this->headers = [];
        foreach ($headers as $header) {
            $aux = explode(':', $header, 2);
            if (sizeof($aux) == 2) {
                $this->headers[$aux[0]] = $aux[1];
            }
        }
    }

    /**
     *
     */
    private function processBody()
    {
        $_body = Tools::substr($this->response, $this->header_size);

        $this->body = json_decode($_body, true);
        if (is_null($this->body)) {
            $this->body  = $_body;
        }
    }

    /**
     * @return mixed
     */
    public function getBody()
    {
        return $this->body;
    }

    /**
     * @return array
     */
    public function getHeaders()
    {
        return $this->headers;
    }

    /**
     * @return array
     */
    public function setRequestHeaders($headers)
    {
        return $this->requestHeaders = $headers;
    }

    /**
     * true if Content-Type is application/json
     * @return boolean
     */
    public function isJson()
    {
        return true;
    }
}
